@@ -73,6 +73,7 @@ from chemicals import miscdata
 from chemicals.miscdata import lookup_VDI_tabular_data
 from chemicals import phase_change
 from chemicals.phase_change import *
+from chemicals.identifiers import CAS_to_int
 
 from thermo.vapor_pressure import VaporPressure
 from thermo.heat_capacity import HeatCapacityGas, HeatCapacitySolid
@@ -138,12 +139,6 @@ class EnthalpyVaporization(TDependentProperty):
         None to not extrapolate; see
         :obj:`TDependentProperty <thermo.utils.TDependentProperty>`
         for a full list of all options, [-]
-    poly_fit : tuple(float, float, list[float]), optional
-        Tuple of (Tmin, Tmax, coeffs) representing a prefered fit to the
-        enthalpy of vaporization of the compound; the coefficients are evaluated with
-        horner's method, and the input variable and output are transformed by
-        the default transformations of this object; used instead of any other
-        default method if provided. [-]
     method : str or None, optional
         If specified, use this method by default and do not use the ranked
         sorting; an exception is raised if this is not a valid method for the
@@ -303,11 +298,6 @@ class EnthalpyVaporization(TDependentProperty):
         super(EnthalpyVaporization, self).__init__(extrapolation, **kwargs)
 
 
-    def as_poly_fit(self):
-        return '%s(poly_fit=(%s, %s, %s, %s))' %(self.__class__.__name__,
-                  repr(self.poly_fit_Tmin), repr(self.poly_fit_Tmax),
-                  repr(self.poly_fit_Tc), repr(self.poly_fit_coeffs))
-
     def load_all_methods(self, load_data=True):
         r'''Method which picks out coefficients for the specified chemical
         from the various dictionaries and DataFrames storing it. All data is
@@ -396,9 +386,6 @@ class EnthalpyVaporization(TDependentProperty):
                 VDI_PPDS: phase_change.phase_change_data_VDI_PPDS_4.index,
                 }
 
-    def _set_poly_fit(self, poly_fit):
-        self.poly_fit_Tc = poly_fit[2]
-        super()._set_poly_fit((poly_fit[0], poly_fit[1], poly_fit[3]))
 
     def calculate(self, T, method):
         r'''Method to calculate heat of vaporization of a liquid at
@@ -419,13 +406,7 @@ class EnthalpyVaporization(TDependentProperty):
         Hvap : float
             Heat of vaporization of the liquid at T, [J/mol]
         '''
-        if method == POLY_FIT:
-            if T > self.poly_fit_Tc:
-                Hvap = 0.0
-            else:
-                Hvap = horner(self.poly_fit_coeffs, log(1.0 - T/self.poly_fit_Tc))
-
-        elif method == COOLPROP:
+        if method == COOLPROP:
             Hvap = PropsSI('HMOLAR', 'T', T, 'Q', 1, self.CASRN) - PropsSI('HMOLAR', 'T', T, 'Q', 0, self.CASRN)
         elif method == DIPPR_PERRY_8E:
             Hvap = EQ106(T, *self.Perrys2_150_coeffs)
@@ -555,8 +536,9 @@ class EnthalpyVaporization(TDependentProperty):
 GHARAGHEIZI_HSUB_298 = 'GHARAGHEIZI_HSUB_298'
 GHARAGHEIZI_HSUB = 'GHARAGHEIZI_HSUB'
 CRC_HFUS_HVAP_TM = 'CRC_HFUS_HVAP_TM' # Gets Tm
+WEBBOOK_HSUB = 'WEBBOOK_HSUB'
 
-enthalpy_sublimation_methods = [GHARAGHEIZI_HSUB, CRC_HFUS_HVAP_TM,
+enthalpy_sublimation_methods = [WEBBOOK_HSUB, GHARAGHEIZI_HSUB, CRC_HFUS_HVAP_TM,
                                 GHARAGHEIZI_HSUB_298]
 '''Holds all methods available for the EnthalpySublimation class, for use in
 iterating over them.'''
@@ -591,12 +573,6 @@ class EnthalpySublimation(TDependentProperty):
         None to not extrapolate; see
         :obj:`TDependentProperty <thermo.utils.TDependentProperty>`
         for a full list of all options, [-]
-    poly_fit : tuple(float, float, list[float]), optional
-        Tuple of (Tmin, Tmax, coeffs) representing a prefered fit to the
-        enthalpy of sublimation of the compound; the coefficients are evaluated with
-        horner's method, and the input variable and output are transformed by
-        the default transformations of this object; used instead of any other
-        default method if provided. [-]
     method : str or None, optional
         If specified, use this method by default and do not use the ranked
         sorting; an exception is raised if this is not a valid method for the
@@ -606,7 +582,10 @@ class EnthalpySublimation(TDependentProperty):
     -----
     To iterate over all methods, use the list stored in
     :obj:`enthalpy_sublimation_methods`.
-
+    
+    **WEBBOOK_HSUB**:
+        Enthalpy of sublimation at a constant temperature of 298.15 K as given 
+        in [3]_.
     **GHARAGHEIZI_HSUB_298**:
         Enthalpy of sublimation at a constant temperature of 298 K as given in
         [1]_.
@@ -633,6 +612,8 @@ class EnthalpySublimation(TDependentProperty):
        (September 25, 2013): 265-doi:10.1016/j.fluid.2013.06.046.
     .. [2] Haynes, W.M., Thomas J. Bruno, and David R. Lide. CRC Handbook of
        Chemistry and Physics, 95E. Boca Raton, FL: CRC press, 2014.
+    .. [3] Shen, V.K., Siderius, D.W., Krekelberg, W.P., and Hatch, H.W., Eds.,
+       NIST WebBook, NIST, http://doi.org/10.18434/T4M88Q
     '''
     name = 'Enthalpy of sublimation'
     units = 'J/mol'
@@ -650,7 +631,7 @@ class EnthalpySublimation(TDependentProperty):
     property_max = 1E6
     '''Maximum valid of heat of sublimation. A theoretical concept only.'''
 
-    ranked_methods = [GHARAGHEIZI_HSUB, CRC_HFUS_HVAP_TM,
+    ranked_methods = [WEBBOOK_HSUB, GHARAGHEIZI_HSUB, CRC_HFUS_HVAP_TM,
                       GHARAGHEIZI_HSUB_298]
 
     obj_references = pure_references = ('Cpg', 'Cps', 'Hvap')
@@ -659,7 +640,7 @@ class EnthalpySublimation(TDependentProperty):
 
     custom_args = ('Tm', 'Tt', 'Cpg', 'Cps', 'Hvap')
     def __init__(self, CASRN='', Tm=None, Tt=None, Cpg=None, Cps=None,
-                 Hvap=None, extrapolation=None, **kwargs):
+                 Hvap=None, extrapolation='linear', **kwargs):
         self.CASRN = CASRN
         self.Tm = Tm
         self.Tt = Tt
@@ -682,7 +663,15 @@ class EnthalpySublimation(TDependentProperty):
         '''
         methods = []
         self.T_limits = T_limits = {}
+        CASRN = self.CASRN
+        CASRN_int = None if not CASRN else CAS_to_int(CASRN)
         if load_data:
+            if CASRN_int in miscdata.webbook_data.index and not isnan(float(miscdata.webbook_data.at[CASRN_int, 'Hsub'])):
+                methods.append(WEBBOOK_HSUB)
+                self.webbook_Hsub = float(miscdata.webbook_data.at[CASRN_int, 'Hsub'])
+                if self.Tm is not None:
+                    T_limits[WEBBOOK_HSUB] = (self.Tm, self.Tm)
+
             if self.CASRN in phase_change.Hsub_data_Gharagheizi.index:
                 methods.append(GHARAGHEIZI_HSUB_298)
                 self.GHARAGHEIZI_Hsub = float(phase_change.Hsub_data_Gharagheizi.at[self.CASRN, 'Hsub'])
@@ -725,16 +714,10 @@ class EnthalpySublimation(TDependentProperty):
         Hsub : float
             Heat of sublimation of the solid at T, [J/mol]
         '''
-        if method == POLY_FIT:
-            if T < self.poly_fit_Tmin:
-                Hsub = (T - self.poly_fit_Tmin)*self.poly_fit_Tmin_slope + self.poly_fit_Tmin_value
-            elif T > self.poly_fit_Tmax:
-                Hsub = (T - self.poly_fit_Tmax)*self.poly_fit_Tmax_slope + self.poly_fit_Tmax_value
-            else:
-                Hsub = horner(self.poly_fit_coeffs, T)
-
-        elif method == GHARAGHEIZI_HSUB_298:
+        if method == GHARAGHEIZI_HSUB_298:
             Hsub = self.GHARAGHEIZI_Hsub
+        elif method == WEBBOOK_HSUB:
+            Hsub = self.webbook_Hsub
         elif method == GHARAGHEIZI_HSUB:
             T_base = 298.15
             Hsub = self.GHARAGHEIZI_Hsub
@@ -779,7 +762,7 @@ class EnthalpySublimation(TDependentProperty):
             Whether or not a method is valid
         '''
         validity = True
-        if method in (GHARAGHEIZI_HSUB_298, GHARAGHEIZI_HSUB, CRC_HFUS_HVAP_TM):
+        if method in (GHARAGHEIZI_HSUB_298, GHARAGHEIZI_HSUB, CRC_HFUS_HVAP_TM, WEBBOOK_HSUB):
             validity = True
         else:
             return super(EnthalpySublimation, self).test_method_validity(T, method)
