@@ -199,12 +199,6 @@ class ThermalConductivityLiquid(TPDependentProperty):
         None to not extrapolate; see
         :obj:`TDependentProperty <thermo.utils.TDependentProperty>`
         for a full list of all options, [-]
-    poly_fit : tuple(float, float, list[float]), optional
-        Tuple of (Tmin, Tmax, coeffs) representing a prefered fit to the
-        viscosity of the compound; the coefficients are evaluated with
-        horner's method, and the input variable and output are transformed by
-        the default transformations of this object; used instead of any other
-        default low-pressure method if provided. [-]
     method : str or None, optional
         If specified, use this method by default and do not use the ranked
         sorting; an exception is raised if this is not a valid method for the
@@ -453,13 +447,6 @@ class ThermalConductivityLiquid(TPDependentProperty):
             kl = horner(self.VDI_PPDS_coeffs, T)
         elif method == COOLPROP:
             kl = CoolProp_T_dependent_property(T, self.CASRN, 'L', 'l')
-        elif method == POLY_FIT:
-            if T < self.poly_fit_Tmin:
-                kl = (T - self.poly_fit_Tmin)*self.poly_fit_Tmin_slope + self.poly_fit_Tmin_value
-            elif T > self.poly_fit_Tmax:
-                kl = (T - self.poly_fit_Tmax)*self.poly_fit_Tmax_slope + self.poly_fit_Tmax_value
-            else:
-                kl = horner(self.poly_fit_coeffs, T)
         else:
             return self._base_calculate(T, method)
         return kl
@@ -860,12 +847,6 @@ class ThermalConductivityGas(TPDependentProperty):
         None to not extrapolate; see
         :obj:`TDependentProperty <thermo.utils.TDependentProperty>`
         for a full list of all options, [-]
-    poly_fit : tuple(float, float, list[float]), optional
-        Tuple of (Tmin, Tmax, coeffs) representing a prefered fit to the
-        viscosity of the compound; the coefficients are evaluated with
-        horner's method, and the input variable and output are transformed by
-        the default transformations of this object; used instead of any other
-        default low-pressure method if provided. [-]
     method : str or None, optional
         If specified, use this method by default and do not use the ranked
         sorting; an exception is raised if this is not a valid method for the
@@ -1130,13 +1111,6 @@ class ThermalConductivityGas(TPDependentProperty):
             kg = Bahadori_gas(T, self.MW)
         elif method == COOLPROP:
             kg = CoolProp_T_dependent_property(T, self.CASRN, 'L', 'g')
-        elif method == POLY_FIT:
-            if T < self.poly_fit_Tmin:
-                kg = (T - self.poly_fit_Tmin)*self.poly_fit_Tmin_slope + self.poly_fit_Tmin_value
-            elif T > self.poly_fit_Tmax:
-                kg = (T - self.poly_fit_Tmax)*self.poly_fit_Tmax_slope + self.poly_fit_Tmax_value
-            else:
-                kg = horner(self.poly_fit_coeffs, T)
         else:
             return self._base_calculate(T, method)
         return kg
